# Confectioner

![](https://img.shields.io/badge/version-1.1.0-blue.svg)
[![lifecycle](https://img.shields.io/badge/lifecycle-stable-green.svg)](https://www.tidyverse.org/lifecycle/#stable)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![Coverage](https://raw.githubusercontent.com/8451/confectioner/meta/coverage/coverage.svg)](https://github.com/8451/confectioner/tree/meta/coverage)
[![docs](https://img.shields.io/badge/docs-latest-brightgreen.svg?style=flat)](https://8451.github.io/confectioner)

A modular config framework for Python applications.

## Installation
See our installation guide [here](docs/source/installation.md).

## Usage
See our usage guide [here](docs/source/usage.md).

## Contributing
If you would like to contribute to **confectioner**, please read the
[Contributing Guide](docs/source/contributing.md).

## Changelog
A summary of recent updates to **confectioner** can be found in the
[Changelog](docs/source/changelog.md).

## Maintainers

| Maintainer                                                | Email                    |
|-----------------------------------------------------------|--------------------------|
| [Austin Warner](https://github.com/austinwarner-8451)     | austin.warner@8451.com   |
| [Michael Stoepel](https://github.com/michaelstoepel-8451) | michael.stoepel@8451.com |

## Links
- Report a bug or request a feature: https://github.com/8451/confectioner/issues/new/choose
- Documentation: https://8451.github.io/confectioner
